"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTestCompiler = void 0;
const tslib_1 = require("tslib");
const sinon = require("ts-sinon");
const inversify_1 = require("inversify");
const core_1 = require("@vulcan-sql/core");
const getTestCompiler = (config = {}) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    const container = new inversify_1.Container();
    // Builder and executor
    const stubQueryBuilder = sinon.stubInterface();
    const stubExecutor = sinon.stubInterface();
    stubExecutor.prepare.callsFake(({ parameterIndex }) => tslib_1.__awaiter(void 0, void 0, void 0, function* () { return `$${parameterIndex}`; }));
    stubExecutor.createBuilder.resolves(stubQueryBuilder);
    container.bind(core_1.TYPES.Executor).toConstantValue(stubExecutor);
    // Code loader
    container
        .bind(core_1.TYPES.CompilerLoader)
        .to(core_1.InMemoryCodeLoader)
        .inSingletonScope();
    // Extension
    yield container.loadAsync((0, core_1.extensionModule)(config));
    // Validators
    yield container.loadAsync((0, core_1.validatorLoaderModule)());
    // Compiler
    container.bind(core_1.TYPES.Compiler).to(core_1.NunjucksCompiler).inSingletonScope();
    // Compiler environment
    container
        .bind(core_1.TYPES.CompilerEnvironment)
        .toDynamicValue((context) => {
        return new core_1.RuntimeCompilerEnvironment(context.container.get(core_1.TYPES.CompilerLoader), context.container.getAll(core_1.TYPES.Extension_TemplateEngine), context.container.get(core_1.TYPES.ValidatorLoader));
    })
        .inSingletonScope()
        .whenTargetNamed('runtime');
    container
        .bind(core_1.TYPES.CompilerEnvironment)
        .toDynamicValue((context) => {
        return new core_1.BuildTimeCompilerEnvironment(context.container.getAll(core_1.TYPES.Extension_TemplateEngine), context.container.get(core_1.TYPES.ValidatorLoader));
    })
        .inSingletonScope()
        .whenTargetNamed('compileTime');
    // Options
    container
        .bind(core_1.TYPES.TemplateEngineInputOptions)
        .toConstantValue({
        folderPath: '',
        provider: core_1.TemplateProviderType.LocalFile,
    });
    container
        .bind(core_1.TYPES.TemplateEngineOptions)
        .to(core_1.TemplateEngineOptions)
        .inSingletonScope();
    const compiler = container.get(core_1.TYPES.Compiler);
    const loader = container.get(core_1.TYPES.CompilerLoader);
    return {
        builder: stubQueryBuilder,
        executor: stubExecutor,
        compiler,
        loader,
        compileAndLoad: (template) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
            const { compiledData, metadata } = yield compiler.compile(template);
            loader.setSource('test', compiledData);
            return { compiledData, metadata };
        }),
        execute: (parameters) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
            return yield compiler.execute('test', {
                parameters,
                profileName: 'mocked-profile',
            });
        }),
        getCreatedProfiles: () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
            const calls = stubExecutor.createBuilder.getCalls();
            return calls.map((call) => call.args[0]);
        }),
        getExecutedQueries: () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
            const calls = stubExecutor.createBuilder.getCalls();
            return calls.map((call) => call.args[1]);
        }),
        getCreatedBinding: () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
            const calls = stubExecutor.createBuilder.getCalls();
            return calls.map((call) => call.args[2].getBinding());
        }),
    };
});
exports.getTestCompiler = getTestCompiler;
//# sourceMappingURL=compiler.js.map